summaryrefslogtreecommitdiffstats
path: root/ppapi/c
diff options
context:
space:
mode:
authordmichael@chromium.org <dmichael@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-04-08 21:36:23 +0000
committerdmichael@chromium.org <dmichael@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-04-08 21:36:23 +0000
commit5f2cb1c97b9ea8af6fbb3dae290da52597e806e4 (patch)
tree4eff2c5b59293a1d434e2624a39643629a06ac47 /ppapi/c
parent3c217ae1a9677660cacb51a21d88020f5bbb6047 (diff)
downloadchromium_src-5f2cb1c97b9ea8af6fbb3dae290da52597e806e4.zip
chromium_src-5f2cb1c97b9ea8af6fbb3dae290da52597e806e4.tar.gz
chromium_src-5f2cb1c97b9ea8af6fbb3dae290da52597e806e4.tar.bz2
Reupload of http://codereview.chromium.org/6801053/
My repo got messed up. BUG=None TEST=src/ppapi/tests/test_post_message.cc Review URL: http://codereview.chromium.org/6801053 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@80992 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ppapi/c')
-rw-r--r--ppapi/c/ppb_messaging.h (renamed from ppapi/c/dev/ppb_messaging_dev.h)16
-rw-r--r--ppapi/c/ppp_messaging.h (renamed from ppapi/c/dev/ppp_messaging_dev.h)14
2 files changed, 15 insertions, 15 deletions
diff --git a/ppapi/c/dev/ppb_messaging_dev.h b/ppapi/c/ppb_messaging.h
index 8ae1ac5..68e8b29 100644
--- a/ppapi/c/dev/ppb_messaging_dev.h
+++ b/ppapi/c/ppb_messaging.h
@@ -2,18 +2,18 @@
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
-#ifndef PPAPI_C_DEV_PPB_MESSAGING_DEV_H_
-#define PPAPI_C_DEV_PPB_MESSAGING_DEV_H_
+#ifndef PPAPI_C_PPB_MESSAGING_H_
+#define PPAPI_C_PPB_MESSAGING_H_
#include "ppapi/c/pp_instance.h"
#include "ppapi/c/pp_var.h"
-#define PPB_MESSAGING_DEV_INTERFACE "PPB_Messaging(Dev);0.1"
+#define PPB_MESSAGING_INTERFACE "PPB_Messaging;0.1"
/**
* @file
* This file defines the PPB_Messaging_Dev interface implemented by the browser.
* The PPB_Messaging_Dev interface contains pointers to functions related to
* sending messages to the JavaScript onmessage handler on the DOM element
* associated with a specific module instance.
*
@@ -22,11 +22,11 @@
*/
/**
* The PPB_Messaging_Dev interface contains pointers to functions related to
* sending messages to the JavaScript onmessage handler on the DOM element
* associated with a specific module instance.
*/
-struct PPB_Messaging_Dev {
+struct PPB_Messaging {
/**
* @a PostMessage is a pointer to a function which asynchronously invokes the
* onmessage handler on the DOM element for the given module instance, if one
@@ -78,5 +78,5 @@ struct PPB_Messaging_Dev {
* @}
*/
-#endif /* PPAPI_C_DEV_PPB_MESSAGING_DEV_H_ */
+#endif /* PPAPI_C_PPB_MESSAGING_H_ */
@@ -2,18 +2,18 @@
/**
* @file
- * This file defines the PPB_Messaging_Dev interface implemented by the browser.
- * The PPB_Messaging_Dev interface contains pointers to functions related to
+ * This file defines the PPB_Messaging interface implemented by the browser.
+ * The PPB_Messaging interface contains pointers to functions related to
* sending messages to the JavaScript onmessage handler on the DOM element
* associated with a specific module instance.
@@ -22,11 +22,11 @@
*/
/**
- * The PPB_Messaging_Dev interface contains pointers to functions related to
+ * The PPB_Messaging interface contains pointers to functions related to
* sending messages to the JavaScript onmessage handler on the DOM element
* associated with a specific module instance.
diff --git a/ppapi/c/dev/ppp_messaging_dev.h b/ppapi/c/ppp_messaging.h
index 8a65986..29a1213 100644
--- a/ppapi/c/dev/ppp_messaging_dev.h
+++ b/ppapi/c/ppp_messaging.h
@@ -2,18 +2,18 @@
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
-#ifndef PPAPI_C_DEV_PPP_MESSAGING_DEV_H_
-#define PPAPI_C_DEV_PPP_MESSAGING_DEV_H_
+#ifndef PPAPI_C_PPP_MESSAGING_H_
+#define PPAPI_C_PPP_MESSAGING_H_
#include "ppapi/c/pp_instance.h"
struct PP_Var;
-#define PPP_MESSAGING_DEV_INTERFACE "PPP_Messaging_Dev;0.1"
+#define PPP_MESSAGING_INTERFACE "PPP_Messaging;0.1"
/**
* @file
* This file defines the PPP_Messaging_Dev structure - a series of pointers to
* methods that you must implement if you wish to handle messages posted to the
* module instance via calls to postMessage on the associated DOM element.
*
@@ -24,11 +24,11 @@ struct PP_Var;
*/
/**
* The PPP_Messaging_Dev interface contains pointers to a series of functions
* that you must implement if you wish to handle messages posted to the module
* instance via calls to postMessage on the associated DOM element.
*/
-struct PPP_Messaging_Dev {
+struct PPP_Messaging {
/**
* HandleMessage is a pointer to a function that the browser will call when
* @a postMessage() is invoked on the DOM element for the module instance in
@@ -59,5 +59,5 @@ struct PPP_Messaging_Dev {
/**
* @}
*/
-#endif /* PPAPI_C_DEV_PPP_MESSAGING_DEV_H_ */
+#endif /* PPAPI_C_PPP_MESSAGING_H_ */
@@ -2,18 +2,18 @@
/**
* @file
- * This file defines the PPP_Messaging_Dev structure - a series of pointers to
+ * This file defines the PPP_Messaging structure - a series of pointers to
* methods that you must implement if you wish to handle messages posted to the
* module instance via calls to postMessage on the associated DOM element.
@@ -24,11 +24,11 @@ struct PP_Var;
*/
/**
- * The PPP_Messaging_Dev interface contains pointers to a series of functions
+ * The PPP_Messaging interface contains pointers to a series of functions
* that you must implement if you wish to handle messages posted to the module
* instance via calls to postMessage on the associated DOM element.